@@ -19,6 +19,7 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         >>> m.price(np.arange(80, 121, 10), 100, 1.2)
         array([16.11757214, 10.00786871,  5.64880408,  2.89028476,  1.34128656])
     """
+
     sigma = None
     beta = 0.5
     is_bsm_sigma = False
@@ -37,7 +38,7 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
 
     def params_kw(self):
         params = super().params_kw()
-        extra = {'beta': self.beta}
+        extra = {"beta": self.beta}
         return {**params, **extra}  # Py 3.9, params | extra
 
     def mass_zero(self, spot, texp, log=False):
@@ -45,13 +46,20 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
 
         betac = 1.0 - self.beta
         a = 0.5 / betac
-        sigma_std = np.maximum(self.sigma / np.power(fwd, betac) * np.sqrt(texp), np.finfo(float).eps)
+        sigma_std = np.maximum(
+            self.sigma / np.power(fwd, betac) * np.sqrt(texp), np.finfo(float).eps
+        )
         x = 0.5 / np.square(betac * sigma_std)
 
         if log:
-            log_mass = (a - 1)*np.log(x) - x - np.log(spsp.gamma(a))
-            log_mass += np.log(1 + (a-1)/x*(1 + (a-2)/x*(1 + (a-3)/x*(1 + (a-4)/x))))
-            with np.errstate(divide='ignore'):
+            log_mass = (a - 1) * np.log(x) - x - np.log(spsp.gamma(a))
+            log_mass += np.log(
+                1
+                + (a - 1)
+                / x
+                * (1 + (a - 2) / x * (1 + (a - 3) / x * (1 + (a - 4) / x)))
+            )
+            with np.errstate(divide="ignore"):
                 log_mass = np.where(x > 100, log_mass, np.log(spst.gamma.sf(x=x, a=a)))
             return log_mass
         else:
@@ -69,12 +77,14 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         """
         fwd = self.forward(spot, texp)
         betac = 1.0 - self.beta
-        alpha = self.sigma/np.power(fwd, betac)
-        t0 = 0.5/(betac*alpha)**2
+        alpha = self.sigma / np.power(fwd, betac)
+        t0 = 0.5 / (betac * alpha) ** 2
         return t0
 
     @staticmethod
-    def price_formula(strike, spot, texp, sigma=None, cp=1, beta=0.5, intr=0.0, divr=0.0, is_fwd=False):
+    def price_formula(
+        strike, spot, texp, sigma=None, cp=1, beta=0.5, intr=0.0, divr=0.0, is_fwd=False
+    ):
         """
 
         Args:
@@ -97,15 +107,15 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
 
         betac = 1.0 - beta
         betac_inv = 1.0 / betac
-        alpha = sigma/np.power(fwd, betac)
-        sigma_std = np.maximum(alpha*np.sqrt(texp), np.finfo(float).eps)
+        alpha = sigma / np.power(fwd, betac)
+        sigma_std = np.maximum(alpha * np.sqrt(texp), np.finfo(float).eps)
         kk = strike / fwd
         x = 1.0 / np.square(betac * sigma_std)
         y = np.power(kk, 2 * betac) * x
 
         # Need to clean up the case beta > 0
         if beta > 1.0:
-            raise ValueError('Cannot handle beta value higher than 1.0')
+            raise ValueError("Cannot handle beta value higher than 1.0")
 
         ncx2_sf = spst.ncx2.sf
         ncx2_cdf = spst.ncx2.cdf
@@ -114,7 +124,7 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         price = np.where(
             cp > 0,
             fwd * ncx2_sf(y, 2 + betac_inv, x) - strike * ncx2_cdf(x, betac_inv, y),
-            strike * ncx2_sf(x, betac_inv, y) - fwd * ncx2_cdf(y, 2 + betac_inv, x)
+            strike * ncx2_sf(x, betac_inv, y) - fwd * ncx2_cdf(y, 2 + betac_inv, x),
         )
         return disc_fac * price
 
@@ -127,11 +137,29 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         y = k_star * np.power(strike, 2 / betac_inv)
 
         if self.beta < 1.0:
-            delta = 0.5 * (cp - 1) + spst.ncx2.sf(y, 2 + betac_inv, x) + 2 * x / betac_inv * \
-                    (spst.ncx2.pdf(y, 4 + betac_inv, x) - strike / fwd * spst.ncx2.pdf(x, betac_inv, y))
+            delta = (
+                0.5 * (cp - 1)
+                + spst.ncx2.sf(y, 2 + betac_inv, x)
+                + 2
+                * x
+                / betac_inv
+                * (
+                    spst.ncx2.pdf(y, 4 + betac_inv, x)
+                    - strike / fwd * spst.ncx2.pdf(x, betac_inv, y)
+                )
+            )
         else:
-            delta = 0.5 * (cp - 1) + spst.ncx2.sf(x, -betac_inv, y) - 2 * x / betac_inv * \
-                    (spst.ncx2.pdf(x, -betac_inv, y) - strike / fwd * spst.ncx2.pdf(y, 4 - betac_inv, x))
+            delta = (
+                0.5 * (cp - 1)
+                + spst.ncx2.sf(x, -betac_inv, y)
+                - 2
+                * x
+                / betac_inv
+                * (
+                    spst.ncx2.pdf(x, -betac_inv, y)
+                    - strike / fwd * spst.ncx2.pdf(y, 4 - betac_inv, x)
+                )
+            )
 
         delta *= df if self.is_fwd else divf
         return delta
@@ -141,13 +169,15 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
 
         betac = 1.0 - self.beta
         betac_inv = 1.0 / betac
-        alpha = self.sigma/np.power(fwd, betac)
-        sigma_std = np.maximum(alpha*np.sqrt(texp), np.finfo(float).eps)
+        alpha = self.sigma / np.power(fwd, betac)
+        sigma_std = np.maximum(alpha * np.sqrt(texp), np.finfo(float).eps)
         kk = strike / fwd
         x = 1.0 / np.square(betac * sigma_std)
         y = np.power(kk, 2 * betac) * x
 
-        cdf = np.where(cp > 0, spst.ncx2.cdf(x, betac_inv, y), spst.ncx2.sf(x, betac_inv, y))
+        cdf = np.where(
+            cp > 0, spst.ncx2.cdf(x, betac_inv, y), spst.ncx2.sf(x, betac_inv, y)
+        )
         return cdf
 
     def gamma(self, strike, spot, texp, cp=1):
@@ -159,17 +189,29 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         y = k_star * np.power(strike, 2 / betac_inv)
 
         if self.beta < 1.0:
-            gamma = (2 + betac_inv - x) * spst.ncx2.pdf(y, 4 + betac_inv, x) + x * spst.ncx2.pdf(y, 6 + betac_inv, x) + \
-                    strike / fwd * (x * spst.ncx2.pdf(x, betac_inv, y) - y * spst.ncx2.pdf(x, 2 + betac_inv, y))
+            gamma = (
+                (2 + betac_inv - x) * spst.ncx2.pdf(y, 4 + betac_inv, x)
+                + x * spst.ncx2.pdf(y, 6 + betac_inv, x)
+                + strike
+                / fwd
+                * (
+                    x * spst.ncx2.pdf(x, betac_inv, y)
+                    - y * spst.ncx2.pdf(x, 2 + betac_inv, y)
+                )
+            )
         else:
-            gamma = (x * spst.ncx2.pdf(x, -betac_inv, y) - y * spst.ncx2.pdf(x, 2 - betac_inv, y)) + \
-                    strike / fwd * ((2 - betac_inv - x) * spst.ncx2.pdf(y, 4 - betac_inv, x) + \
-                                    x * spst.ncx2.pdf(y, 6 - betac_inv, x))
+            gamma = (
+                x * spst.ncx2.pdf(x, -betac_inv, y)
+                - y * spst.ncx2.pdf(x, 2 - betac_inv, y)
+            ) + strike / fwd * (
+                (2 - betac_inv - x) * spst.ncx2.pdf(y, 4 - betac_inv, x)
+                + x * spst.ncx2.pdf(y, 6 - betac_inv, x)
+            )
 
-        gamma *= 2 * (divf/betac_inv)**2 / df * x / fwd
+        gamma *= 2 * (divf / betac_inv) ** 2 / df * x / fwd
 
         if self.is_fwd:
-            gamma *= (df/divf)**2
+            gamma *= (df / divf) ** 2
 
         return gamma
 
@@ -184,9 +226,13 @@ class Cev(opt.OptAnalyticABC, smile.OptSmileABC, smile.MassZeroABC):
         y = k_star * np.power(strike, 2 / betac_inv)
 
         if self.beta < 1.0:
-            vega = - fwd * spst.ncx2.pdf(y, 4 + betac_inv, x) + strike * spst.ncx2.pdf(x, betac_inv, y)
+            vega = -fwd * spst.ncx2.pdf(y, 4 + betac_inv, x) + strike * spst.ncx2.pdf(
+                x, betac_inv, y
+            )
         else:
-            vega = fwd * spst.ncx2.pdf(x, -betac_inv, y) - strike * spst.ncx2.pdf(y, 4 - betac_inv, x)
+            vega = fwd * spst.ncx2.pdf(x, -betac_inv, y) - strike * spst.ncx2.pdf(
+                y, 4 - betac_inv, x
+            )
 
         sigma = self.sigma * spot ** (self.beta - 1)
 
