@@ -16,7 +16,7 @@ from .bsm import Bsm
 from .norm import Norm
 
 
-class Sv32CondMcQE:
+class Sv32McCondQE:
     """
     Conditional MC for 3/2 model based on QE discretization scheme by Andersen(2008)
 
@@ -30,7 +30,7 @@ class Sv32CondMcQE:
         >>> forward = 100
         >>> delta = [1, 1/2, 1/4, 1/8, 1/16, 1/32]
         >>> vov, kappa, rho, texp, theta, sigma = [1, 0.5, -0.9, 10, 0.04, np.sqrt(0.04)]
-        >>> sv32_cmc_qe = pf.Sv32CondMcQE(vov=vov, kappa=kappa, rho=rho, theta=theta)
+        >>> sv32_cmc_qe = pf.Sv32McCondQE(vov=vov, kappa=kappa, rho=rho, theta=theta)
         >>> price_cmc = np.zeros([len(delta), len(strike)])
         >>> for d in range(len(delta)):
         >>>     price_cmc[d, :] = sv32_cmc_qe.price(strike, forward, texp, sigma=sigma, delta=delta[d], path=1e5, seed=123456)
